.. _salt-community:

========================
Salt Community Resources
========================

.. rubric:: Join the Salt!

There are many ways to participate in and communicate with the Salt community.

Salt has an active IRC channel and a mailing list.

Mailing List
============

Join the `salt-users mailing list`_. It is the best place to ask questions
about Salt and see whats going on with Salt development! The Salt mailing list
is hosted by Google Groups. It is open to new members.

.. _`salt-users mailing list`: https://groups.google.com/forum/#!forum/salt-users

Additionally, all users of Salt should be subscribed to the Announcements mailing
list which contains important updates about Salt, such as new releaes and
security-related announcements. This list is low-traffic.

.. _`salt-announce mailing list`: https://groups.google.com/forum/#!forum/salt-announce

IRC
===

The ``#salt`` IRC channel is hosted on the popular `LiberaChat`_ network. You
can use the `LiberaChat webchat client`_ right from your browser.  `Logs of the
IRC channel activity`_ are also available.

.. _LiberaChat: https://libera.chat/
.. _`LiberaChat webchat client`: https://web.libera.chat/#salt
.. _`Logs of the IRC channel activity`: http://ngxbot.nginx.org/logs/%23salt/

If you wish to discuss the development of Salt itself join us in ``#salt-devel``.


Follow on Github
================

The Salt code is developed via Github. Follow Salt for constant updates on what
is happening in Salt development:

|saltrepo|

Long-term planning and strategic decisions are handled via Salt Enhancement Proposals
and can be found on GitHub.

.. _`Salt Enhancement Proposals`: https://github.com/saltstack/salt-enhancement-proposals


Blogs
=====

The Salt Project keeps a `blog`_ with recent news and advancements:

https://saltproject.io/blog/

.. _`blog`: https://saltproject.io/blog/


Example Salt States
===================

The official ``salt-states`` repository is:
https://github.com/saltstack/salt-states

A few examples of salt states from the community:

* https://github.com/blast-hardcheese/blast-salt-states
* https://github.com/kevingranade/kevingranade-salt-state
* https://github.com/uggedal/states
* https://github.com/mattmcclean/salt-openstack/tree/master/salt
* https://github.com/rentalita/ubuntu-setup/
* https://github.com/brutasse/states
* https://github.com/pcrews/salt-data

Follow on ohloh
===============

https://www.ohloh.net/p/salt

Other community links
=====================

- `Salt Project <http://saltproject.io>`_
- `Subreddit <http://www.reddit.com/r/saltstack>`_
- `YouTube <https://www.youtube.com/channel/UCpveTIucFx9ljGelW63-BWg>`_
- `Twitch <https://twitch.tv/saltprojectoss>`_
- `Facebook <https://www.facebook.com/SaltProjectOSS>`_
- `Twitter <https://twitter.com/Salt_Project_OS>`_
- `Wikipedia page <https://en.wikipedia.org/wiki/Salt_(software)>`_
- `Stack Overflow <https://stackoverflow.com/questions/tagged/salt-stack+or+salt-cloud+or+salt-creation>`_

Hack the Source
===============

If you want to get involved with the development of source code or the
documentation efforts, please review the :ref:`contributing documentation
<contributing>`!

.. _`Apache 2.0 license`: http://www.apache.org/licenses/LICENSE-2.0.html
